==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/WidgetMessageDisplay.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

/** Amount of log lines to display */
@JsonSerialize(using = WidgetMessageDisplay.WidgetMessageDisplaySerializer.class)
public class WidgetMessageDisplay {

  public static final WidgetMessageDisplay INLINE = new WidgetMessageDisplay("inline");
  public static final WidgetMessageDisplay EXPANDED_MEDIUM =
      new WidgetMessageDisplay("expanded-md");
  public static final WidgetMessageDisplay EXPANDED_LARGE = new WidgetMessageDisplay("expanded-lg");

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("inline", "expanded-md", "expanded-lg"));

  private String value;

  public boolean isValid() {
    return allowedValues.contains(this.value);
  }

  WidgetMessageDisplay(String value) {
    this.value = value;
  }

  public static class WidgetMessageDisplaySerializer extends StdSerializer<WidgetMessageDisplay> {
    public WidgetMessageDisplaySerializer(Class<WidgetMessageDisplay> t) {
      super(t);
    }

    public WidgetMessageDisplaySerializer() {
      this(null);
    }

    @Override
    public void serialize(
        WidgetMessageDisplay value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonValue
  public String getValue() {
    return this.value;
  }

  public void setValue(String value) {
    this.value = value;
  }

  /** Return true if this WidgetMessageDisplay object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    return this.value.equals(((WidgetMessageDisplay) o).value);
  }

  @Override
  public int hashCode() {
    return Objects.hash(value);
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static WidgetMessageDisplay fromValue(String value) {
    return new WidgetMessageDisplay(value);
  }
}

==> datadog-api-client-2.28.0-sources.jar: com/datadog/api/client/v1/model/WidgetMessageDisplay.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.datadog.api.client.ModelEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/** Amount of log lines to display */
@JsonSerialize(using = WidgetMessageDisplay.WidgetMessageDisplaySerializer.class)
public class WidgetMessageDisplay extends ModelEnum<String> {

  private static final Set<String> allowedValues =
      new HashSet<String>(Arrays.asList("inline", "expanded-md", "expanded-lg"));

  public static final WidgetMessageDisplay INLINE = new WidgetMessageDisplay("inline");
  public static final WidgetMessageDisplay EXPANDED_MEDIUM =
      new WidgetMessageDisplay("expanded-md");
  public static final WidgetMessageDisplay EXPANDED_LARGE = new WidgetMessageDisplay("expanded-lg");

  WidgetMessageDisplay(String value) {
    super(value, allowedValues);
  }

  public static class WidgetMessageDisplaySerializer extends StdSerializer<WidgetMessageDisplay> {
    public WidgetMessageDisplaySerializer(Class<WidgetMessageDisplay> t) {
      super(t);
    }

    public WidgetMessageDisplaySerializer() {
      this(null);
    }

    @Override
    public void serialize(
        WidgetMessageDisplay value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonCreator
  public static WidgetMessageDisplay fromValue(String value) {
    return new WidgetMessageDisplay(value);
  }
}
